@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2023, Intel Corporation
+* Copyright (c) 2018-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -198,6 +198,10 @@ MOS_STATUS DecodePipeline::Initialize(void *settings)
     m_delayMiliseconds = ReadUserFeature(m_userSettingPtr, "Delay Miliseconds", MediaUserSetting::Group::Sequence).Get<uint32_t>();
 #endif
 
+#if MHW_HWCMDPARSER_ENABLED
+    mhw::HwcmdParser::InitInstance(m_osInterface, mhw::HwcmdParser::AddOnMode::NoAddOn);
+#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -292,6 +296,15 @@ MOS_STATUS DecodePipeline::Prepare(void *params)
 
     DECODE_CHK_STATUS(Mos_Solo_SetGpuAppTaskEvent(m_osInterface, decodeParams->m_gpuAppTaskEvent));
 
+#if MHW_HWCMDPARSER_ENABLED
+    auto instance = mhw::HwcmdParser::GetInstance();
+    if (instance)
+    {
+        // use I as default frame type
+        instance->Update('I', (void *)m_featureManager, mhw::HwcmdParser::WorkloadType::Decode);
+    }
+#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -532,16 +545,17 @@ MOS_STATUS DecodePipeline::DumpOutput(const DecodeStatusReportData& reportData)
             }
         }
 
-        if (reportData.currHistogramOutBuf != nullptr &&
-            !Mos_ResourceIsNull(reportData.currHistogramOutBuf))
-        {
-            DECODE_CHK_STATUS(m_debugInterface->DumpBuffer(
-                reportData.currHistogramOutBuf,
-                CodechalDbgAttr::attrSfcHistogram,
-                "_DEC",
-                HISTOGRAM_BINCOUNT * downSamplingFeature->m_histogramBinWidth));
-        }
     }
+    if (reportData.currHistogramOutBuf != nullptr &&
+        !Mos_ResourceIsNull(reportData.currHistogramOutBuf))
+    {
+        DECODE_CHK_STATUS(m_debugInterface->DumpBuffer(
+            reportData.currHistogramOutBuf,
+            CodechalDbgAttr::attrSfcHistogram,
+            "_DEC",
+            HISTOGRAM_BINCOUNT * downSamplingFeature->m_histogramBinWidth));
+    }
+
 #endif
 
     return MOS_STATUS_SUCCESS;
@@ -553,8 +567,18 @@ MOS_STATUS DecodePipeline::ReportVdboxIds(const DecodeStatusMfx& status)
 {
     DECODE_FUNC_CALL();
 
-    // report the VDBOX IDs to user feature
-    uint32_t vdboxIds = ReadUserFeature(m_userSettingPtr, "Used VDBOX ID", MediaUserSetting::Group::Sequence).Get<uint32_t>();
+    uint32_t vdboxIds = 0;
+    uint32_t reportedVdboxIds = 0;
+    // Must add MEDIA_USER_SETTING_INTERNAL_REPORT for different reading path.
+    ReadUserSettingForDebug(
+        m_userSettingPtr,
+        reportedVdboxIds,
+        "Used VDBOX ID",
+        MediaUserSetting::Group::Sequence,
+        0,
+        false,
+        MEDIA_USER_SETTING_INTERNAL_REPORT);
+    vdboxIds = reportedVdboxIds;
     for (auto i = 0; i < csInstanceIdMax; i++)
     {
         CsEngineId csEngineId;
@@ -567,7 +591,7 @@ MOS_STATUS DecodePipeline::ReportVdboxIds(const DecodeStatusMfx& status)
         }
     }
 
-    if (vdboxIds != 0)
+    if (vdboxIds != reportedVdboxIds)
     {
         WriteUserFeature(__MEDIA_USER_FEATURE_VALUE_VDBOX_ID_USED, vdboxIds, m_osInterface->pOsContext);
     }
@@ -608,6 +632,15 @@ MOS_STATUS DecodePipeline::StatusCheck()
 {
     DECODE_FUNC_CALL();
 
+#if MHW_HWCMDPARSER_ENABLED
+    auto instance = mhw::HwcmdParser::GetInstance();
+    if (instance)
+    {
+        // Json dump for each frame
+        instance->DumpOutput();
+    }
+#endif
+
 #if (_DEBUG || _RELEASE_INTERNAL)
     if (m_delayMiliseconds > 0)
     {
